@@ -22,7 +22,9 @@ FunctionalPerl - functional programming on Perl
 
 =head1 DESCRIPTION
 
-Currently just embeds the version variable.
+Allow Perl programs to be written with fewer side effects.
+
+See the L<Functional Perl|http://functional-perl.org/> home page.
 
 =head1 NOTE
 
@@ -39,6 +41,6 @@ package FunctionalPerl;
 
 use strict; use warnings; use warnings FATAL => 'uninitialized';
 
-our $VERSION= "0.72.1";
+our $VERSION= "0.72.2";
 
 1
